@@ -63,15 +63,29 @@ sem.missing.paths = function(
     }
     
     # Get row number from coefficient table for d-sep variable
-    if(!class(basis.mod.new) %in% "pgls") {
+    if(any(!class(basis.mod.new) %in% "pgls")) {
       
-      row.num = which(basis.set[[i]][1] == attr(terms(basis.mod.new), "term.labels")) + 1 
+      row.num = which(basis.set[[i]][1] == rownames(attr(terms(basis.mod.new), "factors"))[-1]) + 1 
       
       # Get row number if interaction variables are switched
-      if(length(row.num) == 0 & grepl("\\:", basis.set[[i]][1])) {
+      if(length(row.num) == 0 & grepl("\\:|\\*", basis.set[[i]][1])) {
         
-        row.num = which(paste(rev(strsplit(basis.set[[i]][1], ":")[[1]]), collapse = ":") == attr(terms(basis.mod.new), "term.labels")) + 1
+        # If interaction is reported as asterisk, convert to semicolon
+        int = gsub(" \\* ", "\\:", basis.set[[i]][1])
         
+        # Get all combinations of interactions
+        all.ints = sapply(strsplit(int, ":"), function(x) { 
+          
+          datf = expand.grid(rep(list(x), length(x)), stringsAsFactors = FALSE)
+          
+          datf = datf[apply(datf, 1, function(x) !any(duplicated(x))), ]
+          
+          apply(datf, 1, function(x) paste(x, collapse = ":"))
+          
+        } )
+        
+        row.num = which(attr(terms(basis.mod.new), "term.labels") %in% all.ints) + 1
+          
         }
       
       } else {
